timeintervaltools.all_are_intervals_or_trees_or_empty
=====================================================

.. autofunction:: abjad.tools.timeintervaltools.all_are_intervals_or_trees_or_empty.all_are_intervals_or_trees_or_empty
